POSITION_MAP = {
    0: 'PG',
    1: 'SG',
    2: 'SF',
    3: 'PF',
    4: 'C',
    5: 'G',
    6: 'F',
    7: 'SG/SF',
    8: 'G/F',
    9: 'PF/C',
    10: 'F/C',
    11: 'UT',
    12: 'BE',
    13: 'IR',
    14: '',
    15: 'Rookie',
    # reverse
    'PG': 0,
    'SG': 1,
    'SF': 2,
    'PF': 3,
    'C': 4,
    'G': 5,
    'F': 6,
    'SG/SF': 7,
    'G/F': 8,
    'PF/C': 9,
    'F/C': 10,
    'UT': 11,
    'BE': 12,
    'IR': 13,
    'Rookie': 15
}

PRO_TEAM_MAP = {
    0: 'FA',
    1: 'ATL',
    2: 'BOS',
    3: 'NOP',
    4: 'CHI',
    5: 'CLE',
    6: 'DAL',
    7: 'DEN',
    8: 'DET',
    9: 'GSW',
    10: 'HOU',
    11: 'IND',
    12: 'LAC',
    13: 'LAL',
    14: 'MIA',
    15: 'MIL',
    16: 'MIN',
    17: 'BKN',
    18: 'NYK',
    19: 'ORL',
    20: 'PHL',
    21: 'PHO',
    22: 'POR',
    23: 'SAC',
    24: 'SAS',
    25: 'OKC',
    26: 'UTA',
    27: 'WAS',
    28: 'TOR',
    29: 'MEM',
    30: 'CHA',
}

STATS_MAP = {
    '0': 'PTS',
    '1': 'BLK',
    '2': 'STL',
    '3': 'AST',
    '4': 'OREB',
    '5': 'DREB',
    '6': 'REB',
    '7': '',
    '8': '',
    '9': 'PF',
    '10': '',
    '11': 'TO',
    '12': '',
    '13': 'FGM',
    '14': 'FGA',
    '15': 'FTM',
    '16': 'FTA',
    '17': '3PTM',
    '18': '3PTA',
    '19': 'FG%',
    '20': 'FT%',
    '21': '3PT%',
    '22': '',
    '23': '',
    '24': '',
    '25': '',
    '26': '',
    '27': '',
    '28': 'MPG',
    '29': '',
    '30': '',
    '31': '',
    '32': '',
    '33': '',
    '34': '',
    '35': '',
    '36': '',
    '37': '',
    '38': '',
    '39': '',
    '40': 'MIN',
    '41': 'GS',
    '42': 'GP',
    '43': '',
    '44': '',
    '45': '',
    }

STAT_ID_MAP = {
    '10': 'projected',
    '01': 'last_7',
    '02': 'last_15',
    '03': 'last_30'
}

ACTIVITY_MAP = {
    178: 'FA ADDED',
    180: 'WAIVER ADDED',
    179: 'DROPPED',
    181: 'DROPPED',
    239: 'DROPPED',
    244: 'TRADED',
    'FA': 178,
    'WAIVER': 180,
    'TRADED': 244
}
